# WizSDK

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Wizard101 bot Software Development Kit
A wrapper for [WizWalker](https://github.com/StarrFox/wizwalker) bundled with many other useful function.
Designed to make building bots for farming / questing / bazaar sniping / selling / pet training

## documentation

you can find the documentation [here](https://underpaiddev1.github.io/wizSDK/)

you can download these from the gh-pages branch if desired

## install

clone the repo or install from pypi `pip install -U wizsdk`

## discord

join the offical discord [here](https://discord.gg/D9GRrbDzpt)

## development install

This package uses [poetry](https://python-poetry.org/)

```shell script
$ poetry install
```

## building

You'll need the dev install (see above) for this to work

### Docs

```shell script
$ cd docs
$ make html
```
